@@ -6,7 +6,7 @@ from urllib.parse import urlparse
 from conduit_sdk.common.schema import AggregationType, ColumnKind, ColumnType, DataColumnSchema
 from conduit_sdk.errors import ValidationError
 
-from .schema import QueryParams, RequestSchema
+from .schema import LocalizationSchema, QueryParams, RequestSchema
 
 
 def parse_query_params(
@@ -34,6 +34,8 @@ def parse_request_schema(body: dict[str, Any]) -> RequestSchema:
     date_from = _get_body_field(body, 'date_from')
     date_to = _get_body_field(body, 'date_to')
     secrets = _get_body_field(body, 'secrets')
+    timezone = _get_body_field(body, 'timezone')
+    localization = _parse_localization(_get_body_field(body, 'localization'))
 
     return RequestSchema(
         config=config,
@@ -41,6 +43,8 @@ def parse_request_schema(body: dict[str, Any]) -> RequestSchema:
         date_from=date_from,
         date_to=date_to,
         secrets=secrets,
+        timezone=timezone,
+        localization=localization,
     )
 
 
@@ -102,3 +106,21 @@ def _parse_columns(columns: list[dict[str, Any]]) -> list[DataColumnSchema]:
             ),
         )
     return parsed_columns
+
+
+def _parse_localization(localization: dict[str, Any]) -> LocalizationSchema:
+    week_start = _get_body_field(localization, 'week_start')
+    locale = _get_body_field(localization, 'locale')
+    currency = _get_body_field(localization, 'currency')
+    decimal_digits = _get_body_field(localization, 'decimal_digits')
+    money_digits = _get_body_field(localization, 'money_digits')
+    percent_digits = _get_body_field(localization, 'percent_digits')
+
+    return LocalizationSchema(
+        week_start=week_start,
+        locale=locale,
+        currency=currency,
+        decimal_digits=decimal_digits,
+        money_digits=money_digits,
+        percent_digits=percent_digits,
+    )
